default_app_config = "django_admin_safe_login.apps.DjangoAdminSafeLoginConfig"

app_requires = [
    "django_static_jquery3",
    "django_secure_password_input",
    "django_simple_tags",
    "captcha",
]
